@@ -11,18 +11,21 @@ __all__ = [
     "Spec",
     "asdataframe",
     "asframe",
+    "aspandas",
     "asseries",
     "core",
+    "extras",
 ]
-__version__ = "0.9.0"
+__version__ = "0.10.0"
 
 
 # submodules
 from . import core
-from .core.aspandas import *
-from .core.mixins import *
+from . import extras
+from .core.api import *
 from .core.specs import *
 from .core.typing import *
+from .extras.new import *
 
 
 # aliases
